    .badge{
        display: inline-block;
        padding: 3px;
        color: white;
        text-align: center;
        width: 70px;
    }
    .ERROR, .CRITICAL {
        background-color: #d93f0b;
    }
    .WARNING {
        background-color: #fbca04;
    }
    .INFO {
        background-color: #bfd4f2;
    }
    .DEBUG {
        background-color: grey;
    }

    .field{
        display: block;
        padding-bottom: 10px;
    }
    .record .label {
        width : 100px;
        display: inline-block;
        font-weight: bold;
        }


